@@ -1,3 +1,4 @@
+# maps clustering type to int
 resolve.type <- function(type)
 {
   types <- c("covariance", "fixedr", "spherical", "diagonal", "eigenvalues", "all")
@@ -5,6 +6,7 @@ resolve.type <- function(type)
   int.type  
 }
 
+# prepares clustering parameters for C function
 create.cec.params <- function(k, n, type, param)
 {
   params <- rep(list(NA), k)
@@ -26,7 +28,7 @@ create.cec.params <- function(k, n, type, param)
       if (ncol(cov) != n) stop("Illegal argument: illegal parameter for \"covariance\" type.")    
       if (nrow(cov) != n) stop("Illegal argument: illegal parameter for \"covariance\" type.")
       if("try-error" %in% class(try(chol(cov), silent=TRUE))) 
-        stop("Illegal argument: illegal parameter for \"covariance\" type. Matrix must be positive-definite.")
+        stop("Illegal argument: illegal parameter for \"covariance\" type - matrix must be positive-definite.")
       i_cov = solve(cov)  
       params <- rep(list(list(cov, i_cov)), k)
     }
@@ -43,7 +45,8 @@ create.cec.params <- function(k, n, type, param)
       else if (is.vector(param))
         evals <- param
       
-      if (length(evals) != n) stop("Illegal argument: illegal parameter for \"eigenvalues\" type.")
+      if (length(evals) != n) stop("Illegal argument: illegal parameter for \"eigenvalues\" type - invalid length.")
+      if (!all(evals != 0)) stop("Illegal argument: illegal parameter for \"eigenvalues\" type - all values must be greater than 0.")
       params = rep(list(sort(evals)), k)
     }
   }
@@ -62,19 +65,17 @@ create.cec.params <- function(k, n, type, param)
        if (type.i == resolve.type("covariance")) 
        {
          idx <- idx + 1
-         
-         #check param length
+
          if (length(param) < idx)
            stop("Illegal argument: illegal param length.")
 
-         #expect matrix param
          cov <- param[[idx]]
          
          if (!is.array(cov)) stop("Illegal argument: illegal parameter for \"covariance\" type.")    
          if (ncol(cov) != n) stop("Illegal argument: illegal parameter for \"covariance\" type.")    
          if (nrow(cov) != n) stop("Illegal argument: illegal parameter for \"covariance\" type.")
          if("try-error" %in% class(try(chol(cov), silent=TRUE))) 
-           stop("Illegal argument: illegal parameter for \"covariance\" type. Matrix must be positive-definite.")
+           stop("Illegal argument: illegal parameter for \"covariance\" type - matrix must be positive-definite.")
          i.cov = solve(cov)  
        params[[i]] <- list(cov, i.cov)
        }
@@ -82,11 +83,9 @@ create.cec.params <- function(k, n, type, param)
        {
          idx <- idx + 1
          
-         #check param length
          if (length(param) < idx)
            stop("Illegal argument: illegal param length.")
          
-         #expect numeric param
          r = param[[idx]]
          if (length(r) != 1) stop("Illegal argument: illegal parameter for \"fixedr\" type.")
          if (!is.numeric(r)) stop("Illegal argument: illegal parameter for \"fixedr\" type.")
@@ -96,13 +95,14 @@ create.cec.params <- function(k, n, type, param)
        else if ( type.i == resolve.type("eigenvalues"))
        {
          idx <- idx + 1
-         #check param length
+         
          if (length(param) < idx)
            stop("Illegal argument: illegal param length.")         
          
            evals <- param[[idx]]         
          
-         if (length(evals) != n) stop("Illegal argument: illegal parameter for \"eigenvalues\" type.")
+         if (length(evals) != n) stop("Illegal argument: illegal parameter for \"eigenvalues\" type: invalid length.")
+         if (!all(evals != 0)) stop("Illegal argument: illegal parameter for \"eigenvalues\" type: all values must be greater than 0.")
          params[[i]] = sort(evals)
        }
      }          
