@@ -1,5 +1,9 @@
-#ifndef VECTOR_H
-#define	VECTOR_H
+#ifndef ARRAY_H
+#define	ARRAY_H
+
+/*
+ * Simple operations on C arrays.
+ */
 
 void array_fill(double * x, const double val, const int n);
 
@@ -22,5 +26,5 @@ void mean_add_point(const double * mean, double * new_mean,
 void mean_remove_point(const double * mean, double * new_mean,
 	const double * point, const int card, const int n);
 
-#endif	/* VECTOR_H */
+#endif	/* ARRAY_H */
 
