@@ -5,13 +5,9 @@
 
 #define BIG_DOUBLE 100000000000000.0
 
-static inline double compute_energy(const int m, const double hx,
-	const int card)
-{
-    double p = (card / (double) m);
-    return p * (-log(p) + hx);
-}
-
+/*
+ * Performs the CEC algorithm on the cec_context structure.
+ */
 int cec(struct cec_context * cec_context);
 
 #endif	/* CEC_H */
