@@ -2,7 +2,7 @@
 #define	ERRORS_H
 #include "errors.h"
 
-extern const char * const POSITIVE_DEFINITE_ERROR_MSG;
+extern const char * const INVALID_COVARIANCE_ERROR_MSG;
 
 extern const char * const MALLOC_ERROR_MSG;
 
@@ -14,7 +14,7 @@ enum error_code
 {
     NO_ERROR = 0,
     MALLOC_ERROR = 1,
-    POSITIVE_DEFINITE_ERROR = 2,
+    INVALID_COVARIANCE_ERROR = 2,
     ALL_CLUSTERS_REMOVED_ERROR = 3,
     UNKNOWN_ERROR = 4	    
 };
